using System;
using NAnt.Core;
using NAnt.Core.Attributes;
using NAnt.Core.Types;
using VaultClientIntegrationLib;
using VaultClientOperationsLib;
using VaultLib;
using MantisLib;

namespace NAnt.Contrib.Tasks.SourceGearVault 
{
	///<summary>
	///
	///            Commit pending operations at or underneath an array of Vault object paths.
	///            
	///</summary>
	[TaskName("vaultcheckin")]
	public class vaultcheckin : VaultTask
	{
		private VaultFileSet _objectPaths = new VaultFileSet();
		///<summary>
		///An array of paths to Vault objects.  These paths can be either local or repository paths.  If they are repository paths, wildcards can be included see 
		///</summary>
		[BuildElement( "vaultfileset", Required = true )]
		public VaultFileSet objectPaths
		{
			get { return _objectPaths; }
			set { _objectPaths = value;}
		}
		
		private String _unchanged = "UndoCheckout";
		///<summary>
		///Controls how unchanged files are treated.
		///This attribute is optional.  The default value is "UndoCheckout".
		///</summary>
		[TaskAttribute( "unchanged", Required = false )]
		public String unchanged
		{
			get { return _unchanged; }
			set { _unchanged = value;}
		}
		
		private Boolean _keepCheckedOut = false;
		///<summary>
		///Inform the server that you wish to retain the checkout on items.
		///This attribute is optional.  The default value is false.
		///</summary>
		[TaskAttribute( "keepCheckedOut", Required = false )]
		public Boolean keepCheckedOut
		{
			get { return _keepCheckedOut; }
			set { _keepCheckedOut = value;}
		}

        private String _localCopy = "Replace";
        ///<summary>
        ///If unchanged is UnchangedHandler.UndoCheckOut, this parameter controls what is done with any modified local files that are present in the working folder.
        ///This attribute is optional.  The default value is "Replace".
        ///</summary>
        [TaskAttribute("localCopy", Required = false)]
        public String localCopy
        {
            get { return _localCopy; }
            set { _localCopy = value; }
        }

		private String _comment = "";
		///<summary>
		///The comment.
		///This attribute is optional.  The default value is "".
		///</summary>
		[TaskAttribute( "comment", Required = false )]
		public String comment
		{
			get { return _comment; }
			set { _comment = value;}
		}
	
		protected override void ExecuteTask() 
		{
			ServerOperations.GetInstance().UserMessage += new ServerOperations.UserMessageEventHandler(WriteUserMessage);
			ServerOperations.client.Verbose = true;
			CheckLoggedIn();
			CheckRepository();
			string[] pathsobjectPaths = new string[objectPaths.Count];
			int iobjectPaths = 0;
			foreach( string fileName in objectPaths.Paths )
			{
				pathsobjectPaths[iobjectPaths++] = fileName;
			}

            ChangeSetItemColl ret = ServerOperations.ProcessCommandListChangeSet(pathsobjectPaths);
            if (ret.Count > 0)
            {
                ServerOperations.client.Comment = comment;
                ServerOperations.ProcessCommandCheckIn(pathsobjectPaths, (UnchangedHandler)Enum.Parse(typeof(UnchangedHandler), unchanged, true), keepCheckedOut, (LocalCopyType)Enum.Parse(typeof(LocalCopyType), localCopy, true));
            }
			ServerOperations.GetInstance().UserMessage -= new ServerOperations.UserMessageEventHandler(WriteUserMessage);
		}
	}
}
